@@ -17,7 +17,7 @@
 GNRS <- function(political_division_dataframe, batches = NULL){
   
   # Check for internet access
-  if (!is.character(getURL("www.google.com"))) {
+  if (!check_internet()) {
     message("This function requires internet access, please check your connection.")
     return(invisible(NULL))
   }
@@ -82,12 +82,12 @@ GNRS <- function(political_division_dataframe, batches = NULL){
   # Send the request in a "graceful failure" wrapper for CRAN compliance
   tryCatch(expr = results_json <-  postForm(url, .opts=list(postfields= input_json, httpheader=headers)),
            error = function(e) {
-             message("There appears to be a problem reaching the API.") 
-             return(NULL)
+             message("There appears to be a problem reaching the API.")
            })
   
   #Return NULL if API isn't working
-  if(is.null(results_json)){return(invisible(NULL))}
+  if(!exists("results_json")){return(invisible(NULL))}
+  
   
   # Convert JSON results to a data frame
   results <-  fromJSON(results_json)
