@@ -17,11 +17,11 @@
 GNRS_get_counties <- function(state_province_id = "") {
   
   # Check for internet access
-  if (!is.character(getURL("www.google.com"))) {
+  if (!check_internet()) {
     message("This function requires internet access, please check your connection.")
     return(invisible(NULL))
   }
-  
+
   #Check input format
   if(!identical(x = state_province_id, y = "")){
     
@@ -62,18 +62,16 @@ GNRS_get_counties <- function(state_province_id = "") {
   
   # Form the input json, including both options and data
   input_json <- paste0('{"opts":', opts_json, ',"data":', data_json, '}' )
-  
+
   
   # Send the request in a "graceful failure" wrapper for CRAN compliance
-  tryCatch(expr =results_json <-  postForm(url, .opts=list(postfields= input_json, httpheader=headers)),
+  tryCatch(expr = results_json <-  postForm(url, .opts=list(postfields= input_json, httpheader=headers)),
            error = function(e) {
-             message("There appears to be a problem reaching the API.") 
-             return(NULL)
+             message("There appears to be a problem reaching the API.")
            })
   
   #Return NULL if API isn't working
-  if(is.null(results_json)){return(invisible(NULL))}
-  
+  if(!exists("results_json")){return(invisible(NULL))}
   
   
   # Display the results
