@@ -13,7 +13,7 @@
 GNRS_get_states <- function(country_id = ""){
 
   # Check for internet access
-  if (!is.character(getURL("www.google.com"))) {
+  if (!check_internet()) {
     message("This function requires internet access, please check your connection.")
     return(invisible(NULL))
   }
@@ -54,14 +54,13 @@ GNRS_get_states <- function(country_id = ""){
   input_json <- paste0('{"opts":', opts_json, ',"data":', data_json, '}' )
   
   # Send the request in a "graceful failure" wrapper for CRAN compliance
-  tryCatch(expr =results_json <-  postForm(url, .opts=list(postfields= input_json, httpheader=headers)),
+  tryCatch(expr = results_json <-  postForm(url, .opts=list(postfields= input_json, httpheader=headers)),
            error = function(e) {
-             message("There appears to be a problem reaching the API.") 
-             return(NULL)
+             message("There appears to be a problem reaching the API.")
            })
   
   #Return NULL if API isn't working
-  if(is.null(results_json)){return(invisible(NULL))}
+  if(!exists("results_json")){return(invisible(NULL))}
   
   
   
